package eu.jonahbauer.wizard.client.libgdx.actors.game;

import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.scenes.scene2d.Actor;
import eu.jonahbauer.wizard.client.libgdx.GameAtlas;
import eu.jonahbauer.wizard.common.model.Card;
import lombok.Getter;
import lombok.Setter;

import java.util.Collections;
import java.util.EnumMap;
import java.util.Map;

@Getter
@Setter
public class CardActor extends Actor {
    public static final float ASPECT_RATIO = 14f / 9f;
    public static final float PREF_WIDTH = 135;
    public static final float PREF_HEIGHT = 210;

    private static final Map<Card, String> ATLAS_PATHS;

    static {
        var paths = new EnumMap<Card, String>(Card.class);
        for (Card card : Card.values()) {
            paths.put(card, switch ((int)(Math.random() * 4)) {
                case 0 -> GameAtlas.CARDS_BLUE;
                case 1 -> GameAtlas.CARDS_GREEN;
                case 2 -> GameAtlas.CARDS_RED;
                case 3 -> GameAtlas.CARDS_YELLOW;
                default -> throw new AssertionError();
            });
        }
        ATLAS_PATHS = Collections.unmodifiableMap(paths);
    }

    private final TextureAtlas atlas;

    private Card card;
    private TextureRegion background;

    public CardActor(Card card, TextureAtlas atlas) {
        this.atlas = atlas;
        setCard(card);
        setWidth(PREF_WIDTH);
        setHeight(PREF_HEIGHT);
    }

    public void setCard(Card card) {
        this.card = card;
        this.background = atlas.findRegion(ATLAS_PATHS.get(card));
    }

    @Override
    public void draw(Batch batch, float parentAlpha) {
        var color = getColor();
        batch.setColor(color.r, color.g, color.b, color.a * parentAlpha);

        float height = getWidth() * ASPECT_RATIO;
        batch.draw(background, getX(), getY() + getHeight() - height, getOriginX(), getOriginY(), getWidth(), getHeight(), getScaleX(), getScaleY(), getRotation());
    }
}
